@@ -96,7 +96,7 @@ class ChatList(Gtk.ListBox, EventHelper, SignalManager):
             ]
         )
 
-        self._timer_id = GLib.timeout_add_seconds(60, self._update_row_state)
+        app.pulse_manager.add_callback(self._update_row_state)
 
     def do_unroot(self) -> None:
         Gtk.ListBox.do_unroot(self)
@@ -106,7 +106,7 @@ class ChatList(Gtk.ListBox, EventHelper, SignalManager):
         self.set_filter_func(None)
         self.set_header_func(None)
         self.set_sort_func(None)
-        GLib.source_remove(self._timer_id)
+        app.pulse_manager.remove_callback(self._update_row_state)
         app.check_finalize(self)
 
     @property
@@ -431,14 +431,6 @@ class ChatList(Gtk.ListBox, EventHelper, SignalManager):
         if account is not None and account != row.account:
             return False
 
-        group = self._current_filter.group
-        if (
-            group is not None
-            and isinstance(row.contact, BareContact)
-            and group not in row.contact.groups
-        ):
-            return False
-
         is_groupchat = row.type == "groupchat"
         if self._current_filter.type == ChatTypeFilter.CHAT and is_groupchat:
             return False
@@ -446,6 +438,15 @@ class ChatList(Gtk.ListBox, EventHelper, SignalManager):
         if self._current_filter.type == ChatTypeFilter.GROUPCHAT and not is_groupchat:
             return False
 
+        group = self._current_filter.group
+        if group is not None:
+            if is_groupchat:
+                return False
+
+            assert isinstance(row.contact, BareContact)
+            if group not in row.contact.groups:
+                return False
+
         if not self._current_filter_text:
             return True
         text = self._current_filter_text.lower()
